<!--- 
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.

The Original Code is comprised of the PT Calendar directory

The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2010-2016.
All Rights Reserved.

By downloading, modifying, distributing, using and/or accessing any files 
in this directory, you agree to the terms and conditions of the applicable 
end user license agreement.
--->
<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	calendar_widget_month_grid_small_rh.cfm
Summary:
	Render Handler to render out the calendar month grid small view
ADF App:
	pt_calendar
Version:
	4.0
History:
	2011-07-14 - GAC - Created
	2015-09-28 - GAC - Added the request.element.hasData  flag to tell commonspot to always rebuild this renderhandler.
	2015-12-30 - GAC - Updated the LinkedCalendarPage to parse the CS Ext URL
	2016-02-24 - DRM - Resource detection exit
--->

<!--- if this module loads resources, do it here.. --->
<cfscript>
	application.ptCalendar.scripts.loadJQuery();
</cfscript>

<!--- ... then exit if all we're doing is detecting required resources --->
<cfif Request.RenderState.RenderMode EQ "getResources">
	<cfscript>
		// these may or may not be indirectly loaded by scripts this calls, so if we're detecting resources, ONLY, load them now
		// if we're not detecting resources, the scripts themselves will do it
		application.ptCalendar.scripts.loadJQueryUI(themeName=application.ptCalendar.getUItheme());
		application.ptCalendar.scripts.loadQTip();
		application.ptCalendar.scripts.loadJQueryImagesLoaded();
		application.ptCalendar.scripts.loadADFLightbox();
	</cfscript>

  <cfexit>
</cfif>


<cfscript>
	// This script MUST remain dynamic since the data and the generated HTML is modified with a URL parameters
	request.element.isStatic = 0;
	request.element.hasData = 1;
	
	// Get the Configuration and Page Map Values
	appConfig = application.ptCalendar.getAppConfig();
	
	// Set the Event Cache status from the configuration element
	useEventsCache = application.ptCalendar.getEventCacheStatus();
	
	// Get the items from the Display Properties Custom Element
	items = attributes.elementInfo.elementData.propertyValues;
	
	linkedCalendarPage = "";
	linkedCalendarSubsite = "";
	if ( ArrayLen(items) AND StructKeyExists(items[1],"values") ) 
	{
		if ( StructKeyExists(items[1].values,"linkedCalendarPage") )
			linkedCalendarPage = application.ptCalendar.csData.parseCSURL(str=items[1].values.linkedCalendarPage);
		if ( StructKeyExists(items[1].values,"linkedCalendarSubsite") )
			linkedCalendarSubsite = items[1].values.linkedCalendarSubsite;
	}

	/* ** ptCalendar getRenderEventsData SETTINGS *** */
	//  -- THESE MUST ME INCLUDED AT THE TOP OF THE ptCalendar GRID/LIST RenderHandlers (before getRenderEventData)
	// - ptCalendar Date Range designation 
	viewRangeType = "Month";   // (Month/Week/Day)
	viewDisplayType = "Small"; // (Small/Grid/List))
	
	// - ptCalendar EventsCache designation (generally this will be true. May need to set to false for debugging)
	// useEventsCache = false; // (true/false) - Use this as an override for the Global setting that is managed via the Configuration element
	
	/* ** getRenderEventsData SETTINGS *** */
	// ptCalendar date and data processing the calendar renderhandler return as CF query object
	//  -- THIS MUST BE INCLUDED AT THE TOP OF THE ptCalendar GRID/LIST RenderHandlers (after the getRenderEventData Settings)
	eventData = application.ptCalendar.calRenderController.getRenderEventData(
																	displayPropsArray=items
																	,viewRangeType=viewRangeType
																	,useEventsCache=useEventsCache
																);
</cfscript>

<cfoutput>
	<!--- // Render the Calendar View --->
	#application.ptCalendar.calRenderController.createCalendar(
													rangeType=viewRangeType
													,displayType=viewDisplayType
													,calendarData=eventData
													,eventField="eventDate"
													,curYear=request.ptCalendar.thisYear
													,curMonth=request.ptCalendar.thisMonth
													,curDay=request.ptCalendar.thisDay
													,linkedPage = linkedCalendarPage
													,linkedSubsite = linkedCalendarSubsite
												)#
</cfoutput>